@@ -4,6 +4,6 @@ RandomJoke(place="/jokes/random")
 
 RandomName(place="/names/random")
 
-OwnPage(place="/orenAPI/aboutME/",name="myname",what_to_show="oren")
+OwnPage(place="/orenAPI/aboutME/",name="myname",what_to_show="oren",name2="myname1",what_to_show2="oren1",)
 
 CreateAPI("localhost","9896",False)
\ No newline at end of file
